import React, { Component } from 'react';
import { TouchableOpacity, View } from 'react-native';
import PropTypes from 'prop-types';

export default class IconButton extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    backgroundColor: PropTypes.string,
    inactiveBackgroundColor: PropTypes.string,
    borderRadius: PropTypes.number,
    buttonStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    marginTop: PropTypes.number,
    isActive: PropTypes.bool,
    onPress: PropTypes.func,
    width: PropTypes.number,
    height: PropTypes.number
  };

  static defaultProps = {
    backgroundColor: '#1d1d1d',
    inactiveBackgroundColor: '#cfcfcf',
    inactiveIconColor: '#ffffff',
    borderRadius: 3,
    buttonStyle: {},
    marginTop: 0,
    isActive: true,
    onPress: () => {},
    width: 30,
    height: 30
  };

  isExecuted = false;

  onPress = () => {
    if (this.isExecuted) {
      return;
    }

    this.isExecuted = true;

    setTimeout(() => {
      this.isExecuted = false;
    }, 1000);

    this.props.onPress();
  };

  render() {
    const width = this.props.width < 45 ? 45 : this.props.width;
    const height = this.props.height < 45 ? 45 : this.props.height;

    return (
      <TouchableOpacity onPress={this.onPress} disabled={!this.props.isActive} style={{ width: width, height: height }}>
        <View style={{ width: width, height: height, alignItems: 'center', justifyContent: 'center' }}>
          <View style={[
              {
                overflow: 'hidden',
                marginTop: this.props.marginTop,
                alignItems: 'center',
                justifyContent: 'center',
                width: this.props.width,
                height: this.props.height,
                borderRadius: this.props.borderRadius,
                backgroundColor: this.props.isActive ? this.props.backgroundColor : this.props.inactiveBackgroundColor
              },
              this.props.buttonStyle
            ]}
          >
            { this.props.children }
          </View>
        </View>
      </TouchableOpacity>
    );
  }
}
