import React, { Component } from 'react';
import { View } from 'react-native';
import PropTypes from 'prop-types';
import { SimpleLineIcons } from '@expo/vector-icons';

import Touchable from '../components/Touchable';

export default class ListItem extends Component {
  static propTypes = {
    children: PropTypes.oneOfType([
      PropTypes.element,
      PropTypes.array
    ]).isRequired,
    onPress: PropTypes.func,
    leftIcon: PropTypes.element,
    rightIcon: PropTypes.oneOfType([
      PropTypes.string,
      PropTypes.element
    ]),
    rightIconColor: PropTypes.string,
    isBorderTopVisible: PropTypes.bool,
    isBorderBottomVisible: PropTypes.bool,
    borderColor: PropTypes.string,
    marginTop: PropTypes.number,
    backgroundColor: PropTypes.string,
    isActive: PropTypes.bool
  };

  static defaultProps = {
    onPress: () => {},
    leftIcon: null,
    rightIcon: 'default',
    rightIconColor: '#1d1d1d',
    isBorderTopVisible: true,
    isBorderBottomVisible: true,
    borderColor: '#cfcfcf',
    marginTop: 0,
    backgroundColor: 'transparent',
    isActive: true
  };

  isExecuted = false;

  onPress = () => {
    if (this.isExecuted) {
      return;
    }

    this.isExecuted = true;

    setTimeout(() => {
      this.isExecuted = false;
    }, 1000);

    this.props.onPress();
  };

  render() {
    let rightIcon = null;

    if (this.props.rightIcon == 'default') {
      rightIcon = <SimpleLineIcons name="arrow-right" size={23} color={this.props.rightIconColor} />;
    }
    else {
      rightIcon = this.props.rightIcon;
    }

    return (
      <Touchable onPress={this.onPress} disabled={!this.props.isActive}>
        <View style={{ backgroundColor: this.props.backgroundColor, marginTop: this.props.marginTop, height: 60, borderTopWidth: this.props.isBorderTopVisible ? 1 : 0, borderTopColor: this.props.borderColor, borderBottomWidth: this.props.isBorderBottomVisible ? 1 : 0, borderBottomColor: this.props.borderColor, flexDirection: 'row', paddingLeft: this.props.leftIcon ? 0 : 16, paddingRight: this.props.rightIcon ? 0 : 16 }}>
          { this.props.leftIcon &&
            <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
              { this.props.leftIcon }
            </View>
          }
          <View style={{ flex: 1, justifyContent: 'center' }}>
            { this.props.children }
          </View>
          { this.props.rightIcon &&
            <View style={{ width: 60, height: 60, alignItems: 'center', justifyContent: 'center' }}>
              { rightIcon }
            </View>
          }
        </View>
      </Touchable>
    );
  }
}
