import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Button from './Button';

export default class Toggle extends Component {
  static propTypes = {
    children: PropTypes.string.isRequired,
    isChecked: PropTypes.bool.isRequired,
    onChange: PropTypes.func.isRequired,
    uncheckedBackgroundColor: PropTypes.string,
    checkedBackgroundColor: PropTypes.string,
    uncheckedTextColor: PropTypes.string,
    checkedTextColor: PropTypes.string,
    textFontSize: PropTypes.number,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    uncheckedBorderColor: PropTypes.string,
    checkedBorderColor: PropTypes.string,
    buttonStyle: PropTypes.object,
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    marginTop: PropTypes.number,
    marginLeft: PropTypes.number
  };

  static defaultProps = {
    uncheckedBackgroundColor: '#cfcfcf',
    checkedBackgroundColor: '#1d1d1d',
    uncheckedTextColor: '#ffffff',
    checkedTextColor: '#ffffff',
    textFontSize: 16,
    borderRadius: 3,
    borderWidth: 0,
    uncheckedBorderColor: '#cfcfcf',
    checkedBorderColor: '#1d1d1d',
    buttonStyle: {},
    textStyle: {},
    marginTop: 0,
    marginLeft: 0
  };

  onPress = () => {
    this.props.onChange(!this.props.isChecked, this.props.children);
  };

  render() {
    return (
      <Button
        onPress={this.onPress}
        backgroundColor={this.props.isChecked ? this.props.checkedBackgroundColor : this.props.uncheckedBackgroundColor}
        buttonStyle={[{ height: 40 }, this.props.buttonStyle]}
        textColor={this.props.isChecked ? this.props.checkedTextColor : this.props.uncheckedTextColor}
        borderRadius={this.props.borderRadius}
        textStyle={this.props.textStyle}
        marginTop={this.props.marginTop}
        marginLeft={this.props.marginLeft}
        textFontSize={this.props.textFontSize}
        borderWidth={this.props.borderWidth}
        borderColor={this.props.isChecked ? this.props.checkedBorderColor : this.props.uncheckedBorderColor}
      >
        { this.props.children }
      </Button>
    );
  }
}
