import React, { Component } from 'react';
import { View } from 'react-native';
import PropTypes from 'prop-types';
import _ from 'lodash';

import Toggle from './Toggle';

export default class Toggles extends Component {
  constructor(props) {
    super(props);

    this.state = this.getState(props);
  }

  static propTypes = {
    values: PropTypes.object.isRequired,
    checkedValues: PropTypes.array,
    checkedKeys: PropTypes.array,
    marginTop: PropTypes.number,
    onChange: PropTypes.func,
    isEqualWidth: PropTypes.bool,
    max: PropTypes.number,
    uncheckedBackgroundColor: PropTypes.string,
    checkedBackgroundColor: PropTypes.string,
    uncheckedTextColor: PropTypes.string,
    checkedTextColor: PropTypes.string,
    textFontSize: PropTypes.number,
    borderRadius: PropTypes.number,
    borderWidth: PropTypes.number,
    uncheckedBorderColor: PropTypes.string,
    checkedBorderColor: PropTypes.string,
    buttonStyle: PropTypes.object,
    textStyle: PropTypes.oneOfType([
      PropTypes.object,
      PropTypes.array
    ]),
    name: PropTypes.string
  };

  static defaultProps = {
    checkedValues: [],
    checkedKeys: [],
    marginTop: 0,
    onChange: () => {},
    isEqualWidth: true,
    max: 0,
    uncheckedBackgroundColor: '#cfcfcf',
    checkedBackgroundColor: '#1d1d1d',
    uncheckedTextColor: '#ffffff',
    checkedTextColor: '#ffffff',
    textFontSize: 16,
    borderRadius: 3,
    borderWidth: 0,
    uncheckedBorderColor: '#cfcfcf',
    checkedBorderColor: '#1d1d1d',
    buttonStyle: {},
    textStyle: {},
    name: ''
  };

  componentWillReceiveProps(nextProps) {
    this.setState(this.getState(nextProps));
  }

  getState = (props) => {
    const state = {};

    if (props.checkedValues.length != 0 || (props.checkedValues.length == 0 && props.checkedKeys.length == 0)) {
      _.forEach(props.values, (value, key) => {
        if (_.find(props.checkedValues, (checkedValue) => {
            return checkedValue == value;
          })) {
          _.extend(state, {
            [`is${key}Checked`]: true
          });
        }
        else {
          _.extend(state, {
            [`is${key}Checked`]: false
          });
        }
      });
    }
    else {
      _.forEach(props.values, (value, key) => {
        if (_.find(props.checkedKeys, (checkedKey) => {
            return checkedKey == key;
          })) {
          _.extend(state, {
            [`is${key}Checked`]: true
          });
        }
        else {
          _.extend(state, {
            [`is${key}Checked`]: false
          });
        }
      });
    }

    return state;
  };

  onChange = (isChecked, value, key) => {
    const count = _.reduce(this.state, (sum, value) => {
      if (value) {
        return sum + 1;
      }
      else {
        return sum;
      }
    }, 0);

    if (count >= this.props.max && this.props.max > 0 && isChecked) {
      return;
    }

    const state = _.cloneDeep(this.state);

    state[`is${key}Checked`] = isChecked;

    const checkedValues = _.reduce(this.props.values, (result, value, key) => {
      if (state[`is${key}Checked`]) {
        result.push(value);
      }

      return result;
    }, []);

    const checkedKeys = _.reduce(this.props.values, (result, value, key) => {
      if (state[`is${key}Checked`]) {
        result.push(key);
      }

      return result;
    }, []);

    this.setState({
      [`is${key}Checked`]: isChecked
    });

    this.props.onChange(checkedValues, checkedKeys, this.props.name);
  };

  renderToggles = () => {
    return _.map(this.props.values, (value, key) => {
      if (this.props.isEqualWidth) {
        return (
          <View style={{ width: '30%', marginLeft: 10, marginTop: 10 }} key={key}>
            <Toggle
              onChange={(isChecked, value) => { this.onChange(isChecked, value, key); }}
              isChecked={this.state[`is${key}Checked`]}
              uncheckedBackgroundColor={this.props.uncheckedBackgroundColor}
              checkedBackgroundColor={this.props.checkedBackgroundColor}
              uncheckedTextColor={this.props.uncheckedTextColor}
              checkedTextColor={this.props.checkedTextColor}
              borderRadius={this.props.borderRadius}
              buttonStyle={this.props.buttonStyle}
              textStyle={this.props.textStyle}
              textFontSize={this.props.textFontSize}
              borderWidth={this.props.borderWidth}
              uncheckedBorderColor={this.props.uncheckedBorderColor}
              checkedBorderColor={this.props.checkedBorderColor}
            >{ value }</Toggle>
          </View>
        );
      }
      else {
        return (
          <View style={{ marginLeft: 10, marginTop: 10 }} key={key}>
            <Toggle
              onChange={(isChecked, value) => { this.onChange(isChecked, value, key); }}
              isChecked={this.state[`is${key}Checked`]}
              uncheckedBackgroundColor={this.props.uncheckedBackgroundColor}
              checkedBackgroundColor={this.props.checkedBackgroundColor}
              uncheckedTextColor={this.props.uncheckedTextColor}
              checkedTextColor={this.props.checkedTextColor}
              borderRadius={this.props.borderRadius}
              buttonStyle={this.props.buttonStyle}
              textStyle={this.props.textStyle}
              textFontSize={this.props.textFontSize}
              borderWidth={this.props.borderWidth}
              uncheckedBorderColor={this.props.uncheckedBorderColor}
              checkedBorderColor={this.props.checkedBorderColor}
            >{ value }</Toggle>
          </View>
        );
      }
    });
  };

  render() {
    return (
      <View style={{ marginTop: this.props.marginTop, flexDirection: 'row', flexWrap: 'wrap' }}>
        { this.renderToggles() }
      </View>
    );
  }
}
